Center class

DSL node for a Center widget.

Usage

Center(
  key: Key('my_center'),
  child: Text('Centered text'),
)
Inheritance

Constructors

Center({Key? key, SduiNode? child})

Properties

child SduiNode?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this node and all its children into the SDUI JSON format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited