Column class

DSL node for a Column widget.

Usage

Column(
  key: Key('my_column'),
  mainAxisAlignment: 'center',
  crossAxisAlignment: 'start',
  children: [
    Text('Hello'),
    Text('World'),
  ],
)

Supported mainAxisAlignment values: start, end, center, spaceBetween, spaceAround, spaceEvenly

Supported crossAxisAlignment values: start, end, center, stretch, baseline

Supported mainAxisSize values: max, min

Inheritance

Constructors

Column({Key? key, String? mainAxisAlignment, String? crossAxisAlignment, String? mainAxisSize, List<SduiNode> children = const []})

Properties

children List<SduiNode>
final
crossAxisAlignment String?
final
hashCode int
The hash code for this object.
no setterinherited
mainAxisAlignment String?
final
mainAxisSize String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this node and all its children into the SDUI JSON format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited