ListView class

DSL node for a ListView widget.

Usage

ListView(
  key: Key('my_list'),
  padding: 16,
  shrinkWrap: true,
  children: [
    Text('Item 1'),
    Text('Item 2'),
  ],
)
Inheritance

Constructors

ListView({Key? key, dynamic padding, bool? shrinkWrap, List<SduiNode> children = const []})

Properties

children List<SduiNode>
final
hashCode int
The hash code for this object.
no setterinherited
padding → dynamic
Padding around the list. A number (all sides) or a map.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkWrap bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this node and all its children into the SDUI JSON format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited