OutlinedButton class
An outlined (bordered) button. See _ButtonBase for all properties.
Constructors
- OutlinedButton({Key? key, required String label, String? labelColor, String? borderColor, double? borderWidth, dynamic borderRadius, double? fontSize, String? fontWeight, dynamic padding, SduiNode? icon, SduiAction? onTap})
Properties
- backgroundColor → String?
-
finalinherited
- borderColor → String?
-
finalinherited
- borderRadius → dynamic
-
finalinherited
- borderWidth → double?
-
finalinherited
- fontSize → double?
-
finalinherited
- fontWeight → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → SduiNode?
-
finalinherited
- label → String
-
finalinherited
- labelColor → String?
-
finalinherited
- onTap → SduiAction?
-
finalinherited
- padding → dynamic
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialises this node and all its children into the SDUI JSON format.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited