Row class

DSL node for a Row widget.

Usage

Row(
  key: Key('my_row'),
  mainAxisAlignment: 'spaceBetween',
  children: [
    Icon(icon: 'star', color: 'Colors.amber'),
    Text('Label'),
  ],
)

Supported mainAxisAlignment: start, end, center, spaceBetween, spaceAround, spaceEvenly

Supported crossAxisAlignment: start, end, center, stretch

Supported mainAxisSize: max, min

Inheritance

Constructors

Row({Key? key, String? mainAxisAlignment, String? crossAxisAlignment, String? mainAxisSize, List<SduiNode> children = const []})

Properties

children List<SduiNode>
final
crossAxisAlignment String?
final
hashCode int
The hash code for this object.
no setterinherited
mainAxisAlignment String?
final
mainAxisSize String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this node and all its children into the SDUI JSON format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited