StatelessWidget class abstract

A mock StatelessWidget that allows developers to define UI using familiar Flutter paradigms instead of top-level variables.

Usage

class MyComponent extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      key: Key('my_component'),
      color: 'Colors.blue',
    );
  }
}
Inheritance

Constructors

StatelessWidget({Key? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialises this node and all its children into the SDUI JSON format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited