Card class
DSL node for a Card widget.
Usage
Card(
key: Key('my_card'),
elevation: 4,
borderRadius: 12,
child: Padding(
padding: 16,
child: Text('Card content'),
),
)
Properties
- borderRadius → dynamic
-
Border radius: a number (uniform) or a map with
tl/tr/bl/br.final - child → SduiNode?
-
final
- elevation → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialises this node and all its children into the SDUI JSON format.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited