Padding class
DSL node for a Padding widget.
Usage
Padding(
key: Key('my_padding'),
padding: 16, // all sides
// or: padding: {'horizontal': 24, 'vertical': 12},
// or: padding: {'left': 8, 'right': 8, 'top': 4, 'bottom': 4},
child: Text('Padded text'),
)
Properties
- child → SduiNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → dynamic
-
Padding value: a number (all sides) or a map with
all/horizontal/vertical/left/top/right/bottom.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialises this node and all its children into the SDUI JSON format.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited