Stack class
DSL node for a Stack widget.
Usage
Stack(
key: Key('my_stack'),
alignment: 'center',
children: [
Container(color: 'Colors.blue', height: 200, width: 200),
Text('Overlay text', color: 'Colors.white'),
],
)
Supported alignment values: topLeft, topCenter, topRight,
centerLeft, center, centerRight, bottomLeft, bottomCenter, bottomRight
Properties
- alignment → String?
-
Alignment of children that do not have a Positioned parent.
final
-
children
→ List<
SduiNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialises this node and all its children into the SDUI JSON format.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited